@@ -1,6 +1,6 @@
 import abc
 
-from typing import Tuple, TypeVar, Generic
+from typing import Tuple, TypeVar, Generic, List
 
 from PIL.Image import Image
 
@@ -35,3 +35,11 @@ class HDFSWrapperBase(Generic[T]):
     @abc.abstractmethod
     def read_txt(self, path: str) -> Tuple[str, RequestResult]:
         pass
+
+    @abc.abstractmethod
+    def mkdir(self, path: str) -> bool:
+        pass
+
+    @abc.abstractmethod
+    def glob(self, path) -> List[str]:
+        pass
\ No newline at end of file
