@@ -14,4 +14,10 @@
 #     main()
 from hdfs_lmdc.hdfs import HDFSWrapperClient
 
-HDFSWrapperClient.load_from_envs()
\ No newline at end of file
+a = HDFSWrapperClient.load_from_envs()
+# a.mkdir("/tmp/oi3")
+# a.upload("/home/thaylon/c.jpg", "/tmp")
+# print(a.glob("/tmp"))
+# result = a.read_image("/tmp/c.jpg")
+# print(a.read_txt("/tmp/producao-terra-2014-1sem.csv"))
+# print(a.download("/tmp/c.jpg", "/tmp")[1].erro)
\ No newline at end of file
